Index: views/controls/textfield/textfield.cc |
=================================================================== |
--- views/controls/textfield/textfield.cc (revision 17014) |
+++ views/controls/textfield/textfield.cc (working copy) |
@@ -1179,13 +1179,14 @@ |
bool Textfield::SkipDefaultKeyEventProcessing(const KeyEvent& e) { |
// TODO(hamaji): Figure out which keyboard combinations we need to add here, |
// similar to LocationBarView::SkipDefaultKeyEventProcessing. |
- if (e.GetCharacter() == VK_BACK) |
+ const int c = e.GetCharacter(); |
+ if (c == VK_BACK) |
return true; // We'll handle BackSpace ourselves. |
// We don't translate accelerators for ALT + NumPad digit, they are used for |
- // entering special characters. |
- if (e.IsAltDown() && |
- win_util::IsNumPadDigit(e.GetCharacter(), e.IsExtendedKey())) |
+ // entering special characters. We do translate alt-home. |
+ if (e.IsAltDown() && (c != VK_HOME) && |
+ win_util::IsNumPadDigit(c, e.IsExtendedKey())) |
return true; |
return false; |